.. _ydoc:

``ydoc``
========

Top-level directives

Single-valued parameters:

  * ``directive_4``: This is a description of Directive 4

  * ``directive_5``: This is a description of Directive 5



Subdirectives:

.. toctree::
   :maxdepth: 1

   ydoc/directive_1
   ydoc/directive_2
   ydoc/directive_3


----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.